#
# spec file for package ghc-some
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name some
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.0.6
Release:        1.2
Summary:        Existential type: Some
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-base-orphans-prof
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}

%description
This library defines an existential type 'Some'.

' data Some f where Some :: f a -> Some f '

in few variants, and utilities to work with it.

If you are unsure which variant to use, use the one in "Data.Some" module.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Oct 24 2023 Peter Simons <psimons@suse.com>
- Update some to version 1.0.6.
  [#] 1.0.6
  - Add instances for `SSymbol`, `SNat` and `SChar` from `base >=4.18.0.0'
* Wed Oct 11 2023 Peter Simons <psimons@suse.com>
- Update some to version 1.0.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Mar 15 2023 Peter Simons <psimons@suse.com>
- Update some to version 1.0.5.
  [#] 1.0.5
  - Add EqP and OrdP classes.
    These are strong versions of Eq1 and Ord1, and on the other hand
    weaker versions of `GEq` and `GCompare`.
    They are exactly what's needed for `Eq` and `Ord` instances of `Some`.
    The naming is unfortunate: `GShow` would be better named `ShowP`,
    as it's similar version of `Show1`.
    Note: we could add `ReadP` with `readsPrecP :: Int -> ReadS (t a)` method,
    but it will barely have any instances.
    `GRead` is different, as it can reify the type index for many types,
    e.g. for the singletons.
    In some future there will be major version of `some` with following
    breaking changes:
  - `EqP` and `OrdP` will become superclasses of `GEq` and `GCompare`
  - `Eq (Some t)` will require `EqP t`, similarly for `Ord` and `OrdP`.
  - `GShow` will get `forall a. Show (f a)` superclass. (This will cause removal of `Product` and `Sum` instances for `base <4.18`).
    To ease future transition you may
  - Define `EqP` and `OrdP` instances for your types.
    The `defaultEq` and `defaultCompare` methods can be used to define
    `eqp` and `comparep` from `GEq` and `GCompare` instances respectively.
  - Move to use `GHC.Generics.:*:` and `:+:` instead of `Data.Functor.Product` and `Sum`, as these have better `Eq` and `Ord` instances.
* Wed Oct  5 2022 Peter Simons <psimons@suse.com>
- Update some to version 1.0.4.1.
  [#] 1.0.4.1
  - Drop support for GHC before 8.6
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update some to version 1.0.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Jun 17 2022 Peter Simons <psimons@suse.com>
- Update some to version 1.0.4.
  [#] 1.0.4
  - Add instances for `(:~~:)`
  - Add instances for `:+:` and `:*:`
  - Add `defaultGeq :: GCompare f => f a -> f b -> Maybe (a :~: b)`
  - Add `defaultGshowsPrec :: Show (t a) => Int -> t a -> ShowS`
* Sat Nov 20 2021 psimons@suse.com
- Update some to version 1.0.3 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update some to version 1.0.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Apr  5 2021 psimons@suse.com
- Add some at version 1.0.3.
